==> haskell-io-streams-haproxy-1.0.1.0-221-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-io-streams-haproxy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 io-streams-haproxy
version:              1.0.1.0
visibility:           public
id:                   io-streams-haproxy-1.0.1.0-EZ5Xnwjx4QHAR2owSKZ5Jd
key:                  io-streams-haproxy-1.0.1.0-EZ5Xnwjx4QHAR2owSKZ5Jd
license:              BSD-3-Clause
copyright:            (c) 2014 Google, Inc. and CONTRIBUTORS
maintainer:           greg@gregorycollins.net
author:               Gregory Collins
homepage:             http://snapframework.com/
synopsis:             HAProxy protocol 1.5 support for io-streams
description:
    HAProxy protocol version 1.5 support (see
    <http://haproxy.1wt.eu/download/1.5/doc/proxy-protocol.txt>) for applications
    using io-streams. The proxy protocol allows information about a networked
    peer (like remote address and port) to be propagated through a forwarding
    proxy that is configured to speak this protocol.

category:             Network, IO-Streams
abi:                  3ff62c2f0c08e8a05a1422d49977e4ee
exposed:              True
exposed-modules:      System.IO.Streams.Network.HAProxy
hidden-modules:       System.IO.Streams.Network.Internal.Address
import-dirs:          /usr/lib/ghc-9.0.2/site-local/io-streams-haproxy-1.0.1.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/io-streams-haproxy-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-io-streams-haproxy
hs-libraries:         HSio-streams-haproxy-1.0.1.0-EZ5Xnwjx4QHAR2owSKZ5Jd
depends:
    attoparsec-0.14.4-DMcS99nTm58Eee5UCcw5RC base-4.15.1.0
    bytestring-0.10.12.1 io-streams-1.5.2.1-Lsi0FpKnDkFCWsx4fcXqxA
    network-3.1.2.7-IOzKcVzyp93ERMKYVerDZf transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-io-streams-haproxy/html/io-streams-haproxy.haddock

haddock-html:         /usr/share/doc/haskell-io-streams-haproxy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-io-streams-haproxy-1.0.1.0-222-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-io-streams-haproxy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 io-streams-haproxy
version:              1.0.1.0
visibility:           public
id:                   io-streams-haproxy-1.0.1.0-G1CUpx9Tn0980QvwRO4mGo
key:                  io-streams-haproxy-1.0.1.0-G1CUpx9Tn0980QvwRO4mGo
license:              BSD-3-Clause
copyright:            (c) 2014 Google, Inc. and CONTRIBUTORS
maintainer:           greg@gregorycollins.net
author:               Gregory Collins
homepage:             http://snapframework.com/
synopsis:             HAProxy protocol 1.5 support for io-streams
description:
    HAProxy protocol version 1.5 support (see
    <http://haproxy.1wt.eu/download/1.5/doc/proxy-protocol.txt>) for applications
    using io-streams. The proxy protocol allows information about a networked
    peer (like remote address and port) to be propagated through a forwarding
    proxy that is configured to speak this protocol.

category:             Network, IO-Streams
abi:                  ea415b5778cfde5e8112f7ab9bcd98fe
exposed:              True
exposed-modules:      System.IO.Streams.Network.HAProxy
hidden-modules:       System.IO.Streams.Network.Internal.Address
import-dirs:          /usr/lib/ghc-9.0.2/site-local/io-streams-haproxy-1.0.1.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/io-streams-haproxy-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-io-streams-haproxy
hs-libraries:         HSio-streams-haproxy-1.0.1.0-G1CUpx9Tn0980QvwRO4mGo
depends:
    attoparsec-0.14.4-9zevo7QnectA1bRgJqQjSQ base-4.15.1.0
    bytestring-0.10.12.1 io-streams-1.5.2.1-8i72hWStfZu2wO5lKopIqb
    network-3.1.2.7-LWaASFO68LfCrj9dzFk83a transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-io-streams-haproxy/html/io-streams-haproxy.haddock

haddock-html:         /usr/share/doc/haskell-io-streams-haproxy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
